/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  base_info: 'Basic Information',
  cluster_config: 'Cluster Configuration',
  cluster_info: 'Cluster',
  component_info: 'Stack',
  component: 'Component',
  host_config: 'Hosts',
  create: 'Create',
  name: 'Name',
  display_name: 'Display Name',
  description: 'Description',
  root_dir: 'Root Dir',
  user_group: 'User Group',
  config_source: 'Repository',
  install_dependencies: 'Install Dependencies',
  add_host: 'Add Host',
  edit_host: 'Edit Host',
  view_log: 'View Log',
  source: 'Repository',
  show_hosts_resolved: 'Resolved Hostnames',
  duplicate_hostname: '{0} host name(s) are duplicated. Please choose how to handle them.',
  exist_duplicate_hostname: 'Duplicate host name found. Choose an action.',
  cluster_unavailable_message: 'Sorry, you need to create cluster to use this feature.',
  keep: 'keep',
  override: 'override'
}
